@@ -2,6 +2,7 @@
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.db import models
+from django.db.models import Q
 from django.utils import timezone
 from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
@@ -14,8 +15,10 @@ class Category(models.Model):
     """
     A blog ``Entry`` can belong to one category.
 
+    :creation_date: Date when this category was created.
     :slug: The slug for this category. The slug will be the same for all
       languages.
+    :parent: Allows you to build hierarchies of categories.
 
     """
     creation_date = models.DateTimeField(auto_now_add=True)
@@ -25,6 +28,12 @@ class Category(models.Model):
         verbose_name=_('Slug'),
     )
 
+    parent = models.ForeignKey(
+        'cmsplugin_blog_categories.Category',
+        verbose_name=_('Parent'),
+        null=True, blank=True,
+    )
+
     def __unicode__(self):
         return self.get_title()
 
@@ -32,8 +41,10 @@ class Category(models.Model):
         """Returns the entries for this category."""
         qs = EntryCategory.objects.select_related()
         qs = qs.filter(
-            category=self, entry__is_published=True,
-            entry__pub_date__lte=timezone.now())
+            Q(category=self) | Q(category__parent=self),
+            entry__is_published=True,
+            entry__pub_date__lte=timezone.now(),
+        )
         qs = qs.order_by('-entry__pub_date')
         return [item.entry for item in qs]
 
@@ -81,8 +92,21 @@ class EntryCategory(models.Model):
 
 
 class CategoryPlugin(CMSPlugin):
-    """Plugin, which renders entries belonging to one or more category."""
+    """
+    Plugin, which renders entries belonging to one or more category.
+
+    :categories: ...
+    :template_argument: Char which is place within templates as True, if you
+      want to alter a template.
+
+    """
     categories = models.ManyToManyField(
         Category,
         verbose_name=_('Category'),
     )
+
+    template_argument = models.CharField(
+        max_length=20,
+        verbose_name=_('Template Argument'),
+        blank=True,
+    )
