@@ -1,7 +1,7 @@
 """URLs of the ``cmsplugin_blog_categories`` app. """
 from django.conf.urls.defaults import include, patterns, url
 
-from cmsplugin_blog_categories.views import CategoryListView
+from .views import GetEntriesAjaxView, CategoryListView
 
 
 urlpatterns = patterns(
@@ -10,5 +10,9 @@ urlpatterns = patterns(
         CategoryListView.as_view(),
         name='blog_archive_category',),
 
+    url(r'^get-entries/',
+        GetEntriesAjaxView.as_view(),
+        name='blog_get_entries',),
+
     url(r'^', include('cmsplugin_blog.urls')),
 )
